# avdiscordutils

provides extra functions for discord channels and roles and is open for future development
current functions provided:
findOne,
findAll,
findOrCreate,
findAndDelete


## Installation

Use the package manager [npm](https://www.npmjs.com/package/avdiscordutils) to install avdiscordutils.

```bash
npm install avdiscordutils --save
```

## Usage

```js
const {Structures} = require('discord.js')
require('avdiscordutils')(Structures);
```
## Examples
### Channel Functions
```js
//find one channel
guild.channels.findOne('exampleChannel')
    .then(channel => console.log(`Channel ${channel.name} has been created`))
    .catch(console.error)

//find one text channel with a random id in it's name
guild.channels.findOne('EF56HG' , {type : 'text'} , {includes : true})
    .then(channel => console.log(`Channel ${channel.name} has been created`))
    .catch(console.error)

//find all text channels with the letter a in it
guild.channels.findAll('a' , {type : 'text'} , {includes : true})
    .then(channels => channels.forEach(channel => console.log(channel.name)))
    .catch(console.error)

//find or create channel
guild.channels.findOrCreate('exampleChannel')
    .then(channel => console.log(`Channel ${channel.name} has been created`))
    .catch(console.error)

//find or create category channel
guild.channels.findOrCreate('exampleChannel' , {type : 'category'})
    .then(channel => console.log(`Channel ${channel.name} has been created`))
    .catch(console.error)

//findOrCreate channel with options
guild.channels.findOrCreate('exampleChannel' , {
  type: 'voice',
  permissionOverwrites: [
     {
       id: message.author.id,
       deny: ['VIEW_CHANNEL'],
    },
  ],
})
    .then(channel => console.log(`Channel ${channel.name} has been created`))
    .catch(console.error)

//find and delete category channel
guild.channels.findAndDelete('exampleChannel' , {type : 'category'})
    .then(result => console.log(result))
    .catch(console.error)
```
### Roles Functions

```js
//find one role
guild.roles.findOne('exampleRole')
    .then(role => console.log(`Role ${role.name} has been created`))
    .catch(console.error)

//find all roles with the letter a in it
guild.roles.findAll('a' , {} , {includes : true})
    .then(roles => roles.forEach(role => console.log(role.name)))
    .catch(console.error)

//find or create role
guild.roles.findOrCreate('exampleRole')
    .then(role => console.log(`Role ${role.name} has been created`))
    .catch(console.error)

//findOrCreate role with options
guild.roles.findOrCreate('exampleRole' , {
  data: {
    name: 'Super Cool People',
    color: 'BLUE',
  },
  reason: 'we needed a role for Super Cool People',
})
    .then(role => console.log(`Role ${role.name} has been created`))
    .catch(console.error)

//find or create role
guild.roles.findAndDelete('exampleRole')
    .then(result => console.log(result))
    .catch(console.error)
```

##functions docs
```js
//channels
guild.channels.findOne(String name_or_id, Object options, Object settings)
guild.channels.findAll(String name_or_id, Object options, Object settings)
guild.channels.findOrCreate(String name_or_id, Object options, Object settings)
guild.channels.findAndDelete(String name_or_id, Object options, Object settings)

//roles
guild.channels.findOne(String name_or_id, Object options, Object settings)
guild.channels.findAll(String name_or_id, Object options, Object settings)
guild.channels.findOrCreate(String name_or_id, Object options, Object settings)
guild.channels.findAndDelete(String name_or_id, Object options, Object settings)
```
the options object can be found on the official [discord documentation](https://discord.js.org/#/docs/main/stable/general/welcome).

findOrCreateChannel [options](https://discord.js.org/#/docs/main/stable/class/GuildChannelManager?scrollTo=create) object

findOrCreateRole [options](https://discord.js.org/#/docs/main/stable/class/RoleManager?scrollTo=create) object

only 1 setting right now; {includes:true/false} which will use the includes function instead of directly comparing the strings when searching

avdiscordutils uses Promises extensively.
This means that, if your Node version supports it, you can use ES2017 async/await syntax for all asynchronous calls made with avdiscordutils.


## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

[GitHub](https://github.com/AVMG20/avdiscordutils)

## License
[MIT](https://choosealicense.com/licenses/mit/)